@@ -69,12 +69,13 @@ class EquationAnimation(MovingCameraScene):
                 tex_string = '\\\\'.join(chunk_words(tex_string, int(W)))
                 T = Tex(tex_string, tex_template=custom_template).scale(ST).next_to(([-0.5*W, PL[1] - 1.5, 0]), RIGHT, buff=1)
                 
-                get_audio(process_tex_to_text(value[0]), key)
+                duration = get_audio(process_tex_to_text(value[0]), key)
                 self.add_sound(f'{key}.aac')
                 self.play(
                     self.camera.frame.animate.move_to(([0, T.get_y(), 0])),
                     Create(T),
-                    run_time=0.03*len(T.get_tex_string())
+                    run_time=duration
+                    #run_time=0.03*len(T.get_tex_string())
                 )
                 PL = T.get_bottom()
             else:
