@@ -4,7 +4,7 @@ import os
 from moviepy.video.io.VideoFileClip import VideoFileClip
 from sympy import *
 
-def copy_animation(frame_height, fps, bg_path):
+def copy_animation(frame_height, fps, bg_path, trim=50):
     source_file = f'./media/videos/{int(frame_height)}p{int(fps)}/EquationAnimation.mp4'
     
     if not os.path.exists(source_file):
@@ -18,9 +18,9 @@ def copy_animation(frame_height, fps, bg_path):
     print(f"Video duration: {video.duration} seconds")
     
     if video.duration > 60:
-        part_1 = f'ffmpeg -i {source_file} -r {fps} -t 50 -async 1 -c copy ./downloads/EquationAnimation_first_half.mp4'
+        part_1 = f'ffmpeg -i {source_file} -r {fps} -t {trim} -async 1 -c copy ./downloads/EquationAnimation_first_half.mp4'
         subprocess.call(part_1, shell=True)
-        part_2 = f'ffmpeg -i {source_file} -r {fps} -ss 00:00:50 -async 1 -c copy ./downloads/EquationAnimation_second_half.mp4'
+        part_2 = f'ffmpeg -i {source_file} -r {fps} -ss 00:00:{trim} -async 1 -c copy ./downloads/EquationAnimation_second_half.mp4'
         
         subprocess.call(part_2, shell=True)
         print("Trimmed and Copied successfully!")
