@@ -10,6 +10,7 @@ def process_tex_to_text(tex_string):
     tex_string = tex_string.replace(r'\intertext{', r'')
     tex_string = tex_string.replace(r'\\[2mm]', r'')
     tex_string = tex_string.replace(r'&', r'')
+    tex_string = tex_string.replace(r'\Rightarrow', r'[[slnc 500]]')
     tex_string = sub(r'}\n', '\n', tex_string) 
     math_expressions = findall(r'\$(.*?)\$', tex_string)
     print(math_expressions)
@@ -25,10 +26,10 @@ def process_tex_to_text(tex_string):
 def get_audio(text, key):
     print(text)
     try:
-        audio_command = f'say -o {key}.aac {text}'
+        audio_command = f'say -o {key}.aac {text} -r 150'
         print(audio_command)
         subprocess.call(audio_command, shell=True) 
-        time.sleep(2) 
+        time.sleep(1) 
         duration = get_audio_duration(f'{key}.aac')
         return duration
     except:
