@@ -83,18 +83,37 @@ bg_path = "/Users/vaibhavblayer/10xphysics/backgrounds/bg_instagram.jpg"
         show_default=True,
         help="End time of the video"
         )
-def main(inputfile, tikzfile, background, pixel_height, pixel_width, frame_rate, frame_height, frame_width, st, se):
-        EquationAnimation(
-                file_sol=inputfile, 
-                file_tikz=tikzfile, 
-                ph=pixel_height, 
-                pw=pixel_width,
-                fr=frame_rate,
-                fh=frame_height,
-                fw=frame_width,
-                ST=st,
-                SE=se).render()
+@click.option(
+        '--copy',
+        type=bool,
+        default=True,
+        show_default=True,
+        help="Copy Animation after rendering"
+        )
+@click.option(
+        '--trim',
+        type=int,
+        default=50,
+        show_default=True,
+        help="Trimming duration of the video"
+        )
+def main(inputfile, tikzfile, background, pixel_height, pixel_width, frame_rate, frame_height, frame_width, st, se, copy, trim):
+        
+        if copy:
+                EquationAnimation(
+                        file_sol=inputfile, 
+                        file_tikz=tikzfile, 
+                        ph=pixel_height, 
+                        pw=pixel_width,
+                        fr=frame_rate,
+                        fh=frame_height,
+                        fw=frame_width,
+                        ST=st,
+                        SE=se).render()
         
         
-        copy_animation(pixel_height, frame_rate, bg_path=background)
+                copy_animation(pixel_height, frame_rate, bg_path=background, trim=trim)
+                
+        else:
+                copy_animation(pixel_height, frame_rate, bg_path=background, trim=trim)
     
\ No newline at end of file
